==> tkimg-1.3-2005-01-05.tar.gz: tkimg-1.3/tkimg.h <==
/*
 * tkimg.h --
 *
 *	Interface to tkimg Base package.
 *
 * Copyright (c) 2002 Andreas Kupries <andreas_kupries@users.sourceforge.net>
 *
 * Zveno Pty Ltd makes this software and associated documentation
 * available free of charge for any purpose.  You may make copies
 * of the software but you must include all of this notice on any copy.
 *
 * Zveno Pty Ltd does not warrant that this software is error free
 * or fit for any purpose.  Zveno Pty Ltd disclaims any liability for
 * all claims, expenses, losses, damages and costs any user may incur
 * as a result of using, copying or modifying the software.
 *
 * $Id: tkimg.h,v 1.5 2004/12/02 01:08:03 hobbs Exp $
 *
 */

#ifndef __TKIMG_H__
#define __TKIMG_H__

#include <stdio.h>
#include "tk.h"

#define TKIMG_VERSION "1.3.99"

/*
 * Used to block the rest of this header file from resource compilers so
 * we can just get the version info.
 */
#ifndef RC_INVOKED

/* TIP 27 update. If CONST84 is not defined we are compiling against a
 * core before 8.4 and have to disable some CONST'ness.
 */

#ifndef CONST84
#   define CONST84
#endif

#if BUILD_tkimg
#	define TKIMG_STORAGE_CLASS DLLEXPORT
#elif USE_TKIMG_STUBS
#	define TKIMG_STORAGE_CLASS /*nothing*/
#else
#	define TKIMG_STORAGE_CLASS DLLIMPORT
#endif

/*
 *----------------------------------------------------------------------------
 * C API for Tkimg generic layer
 *----------------------------------------------------------------------------
 */

typedef struct tkimg_MFile {
    Tcl_DString *buffer;/* pointer to dynamical string */
    char *data;		/* mmencoded source string */
    int c;		/* bits left over from previous char */
    int state;		/* decoder state (0-4 or IMG_DONE) */
    int length;		/* length of physical line already written */
} tkimg_MFile;

#define IMG_SPECIAL	 (1<<8)
#define IMG_PAD		(IMG_SPECIAL+1)
#define IMG_SPACE	(IMG_SPECIAL+2)
#define IMG_BAD		(IMG_SPECIAL+3)
#define IMG_DONE	(IMG_SPECIAL+4)
#define IMG_CHAN        (IMG_SPECIAL+5)
#define IMG_STRING	(IMG_SPECIAL+6)

/*
 *----------------------------------------------------------------------------
 * Function prototypes for publically accessible routines
 *----------------------------------------------------------------------------
 */

/* 0 */
TKIMG_STORAGE_CLASS Tcl_Channel	tkimg_OpenFileChannel _ANSI_ARGS_((
				Tcl_Interp * interp, CONST char * fileName, 
				int permissions));
/* 1 */
TKIMG_STORAGE_CLASS int		tkimg_ReadInit _ANSI_ARGS_((Tcl_Obj * data, int c, 
				tkimg_MFile * handle));
/* 2 */
TKIMG_STORAGE_CLASS void		tkimg_WriteInit _ANSI_ARGS_((Tcl_DString * buffer, 
				tkimg_MFile * handle));
/* 3 */
TKIMG_STORAGE_CLASS int		tkimg_Getc _ANSI_ARGS_((tkimg_MFile * handle));
/* 4 */
TKIMG_STORAGE_CLASS int		tkimg_Read _ANSI_ARGS_((tkimg_MFile * handle, 
				void * dst, int count));
/* 5 */
TKIMG_STORAGE_CLASS int		tkimg_Putc _ANSI_ARGS_((int c, tkimg_MFile * handle));
/* 6 */
TKIMG_STORAGE_CLASS int		tkimg_Write _ANSI_ARGS_((tkimg_MFile * handle, 
				CONST char * src, int count));
/* 7 */
TKIMG_STORAGE_CLASS void		tkimg_ReadBuffer _ANSI_ARGS_((int onOff));
/* Slot 8 is reserved */
/* Slot 9 is reserved */
/* 10 (was tkimg_PhotoPutBlock) */
/* Slot 11 is reserved */
/* Slot 12 is reserved */
/* Slot 13 is reserved */
/* Slot 14 is reserved */
/* Slot 15 is reserved */
/* Slot 16 is reserved */
/* Slot 17 is reserved */
/* Slot 18 is reserved */
/* Slot 19 is reserved */
/* 20 (was FixChanMatchProc) */
/* 21 (was FixObjMatchProc) */
/* 22 (was FixStringWriteProc) */
/* Slot 23 is reserved */
/* Slot 24 is reserved */
/* Slot 25 is reserved */
/* Slot 26 is reserved */
/* Slot 27 is reserved */
/* Slot 28 is reserved */
/* Slot 29 is reserved */
/* 30 - was tkimg_GetStringFromObj */
/* 31 - was tkimg_GetByteArrayFromObj */
/* 32 - was tkimg_ListObjGetElements  */


/*
 *----------------------------------------------------------------------------
 * END 
 *----------------------------------------------------------------------------
 */

/*
 * Convenience macros dealing with the ever-varying signatures 
 * [TIP 98, TIP 116] of various Tk_Photo* routines.
 *
 * Note: The current implementation makes this a compile time decision.
 *       In the future we might realize a runtime decision instead.
 *
 * Default to TK_PHOTO_COMPOSITE_SET (not TK_PHOTO_COMPOSITE_OVERLAY)
 * to have the initial load of images with alpha channels be correct.
 */

#if ((TK_MAJOR_VERSION == 8) && (TK_MINOR_VERSION > 4))
/* TIP 116 */
#define tkimg_PhotoPutBlockTk(interp,hdl,b,x,y,w,h) \
    	Tk_PhotoPutBlock(interp, hdl, b, x, y, w, h, TK_PHOTO_COMPOSITE_SET)
#elif ((TK_MAJOR_VERSION == 8) && (TK_MINOR_VERSION > 3))
/* TIP 98 */
#define tkimg_PhotoPutBlockTk(interp,hdl,b,x,y,w,h) \
	Tk_PhotoPutBlock(hdl, b, x, y, w, h, TK_PHOTO_COMPOSITE_SET)
#else
#define tkimg_PhotoPutBlockTk(interp,hdl,b,x,y,w,h) \
	Tk_PhotoPutBlock(hdl, b, x, y, w, h)
#endif

#if ((TK_MAJOR_VERSION == 8) && (TK_MINOR_VERSION > 4))
/* TIP 116 */
#define tkimg_PhotoExpand(interp,hdl,w,h)  Tk_PhotoExpand(interp, hdl, w, h)
#define tkimg_PhotoSetSize(interp,hdl,w,h) Tk_PhotoSetSize(interp, hdl, w, h)
#else
#define tkimg_PhotoExpand(interp,hdl,w,h)  Tk_PhotoExpand(hdl, w, h)
#define tkimg_PhotoSetSize(interp,hdl,w,h) Tk_PhotoSetSize(hdl, w, h)
#endif

#endif /* RC_INVOKED */
#endif /* __TKIMG_H__ */

==> tkimg-1.3-2008-01-16.tar.gz: tkimg-1.3/tkimg.h <==
/*
 * tkimg.h --
 *	Declarations for internal routines used by Img package.
 */

#ifndef __TKIMG_H__
#define __TKIMG_H__

#include "tk.h"

#define TKIMG_VERSION "1.3.99"

#if BUILD_tkimg
#	define TKIMGAPI DLLEXPORT
#elif USE_TKIMG_STUBS
#	define TKIMGAPI /*nothing*/
#else
#	define TKIMGAPI DLLIMPORT
#endif

/*
 * The tkimg_MFile routines encapsulate the different input sources
 * and output destinations for photo image formats (Tcl_Channels,
 * binary data in Tcl_Obj's, base-64-encoded data, etc.)
 */
typedef struct tkimg_MFile {
    Tcl_DString *buffer;/* pointer to dynamical string */
    char *data;		/* mmencoded source string */
    int c;		/* bits left over from previous char */
    int state;		/* decoder state (0-4 or IMG_DONE) */
    int length;		/* length of physical line already written */
} tkimg_MFile;

#define IMG_SPECIAL	(1<<8)
#define IMG_PAD		(IMG_SPECIAL+1)
#define IMG_SPACE	(IMG_SPECIAL+2)
#define IMG_BAD		(IMG_SPECIAL+3)
#define IMG_DONE	(IMG_SPECIAL+4)
#define IMG_CHAN        (IMG_SPECIAL+5)
#define IMG_STRING	(IMG_SPECIAL+6)

/*
 * Function prototypes:
 */

TKIMGAPI Tcl_Channel tkimg_OpenFileChannel(
	Tcl_Interp *, const char *fileName, int permissions);
TKIMGAPI int tkimg_ReadInit(Tcl_Obj *data, int c, tkimg_MFile *handle);
TKIMGAPI void tkimg_WriteInit(Tcl_DString *buffer, tkimg_MFile *handle);
TKIMGAPI int tkimg_Getc(tkimg_MFile *handle);
TKIMGAPI int tkimg_Read(tkimg_MFile *handle, void * dst, int count);
TKIMGAPI void tkimg_Putc(int c, tkimg_MFile * handle);
TKIMGAPI void tkimg_Finish(tkimg_MFile *handle);
TKIMGAPI int tkimg_Write(tkimg_MFile *handle, const char * src, int count);

/*
 * Convenience macros dealing with the ever-varying signatures 
 * [TIP 98, TIP 116] of various Tk_Photo* routines.
 *
 * Default to TK_PHOTO_COMPOSITE_SET (not TK_PHOTO_COMPOSITE_OVERLAY)
 * to have the initial load of images with alpha channels be correct.
 */

#if ((TK_MAJOR_VERSION == 8) && (TK_MINOR_VERSION > 4))
/* TIP 116 */
#define tkimg_PhotoPutBlockTk(interp,hdl,b,x,y,w,h) \
    	Tk_PhotoPutBlock(interp, hdl, b, x, y, w, h, TK_PHOTO_COMPOSITE_SET)
#elif ((TK_MAJOR_VERSION == 8) && (TK_MINOR_VERSION > 3))
/* TIP 98 */
#define tkimg_PhotoPutBlockTk(interp,hdl,b,x,y,w,h) \
	Tk_PhotoPutBlock(hdl, b, x, y, w, h, TK_PHOTO_COMPOSITE_SET)
#else
#define tkimg_PhotoPutBlockTk(interp,hdl,b,x,y,w,h) \
	Tk_PhotoPutBlock(hdl, b, x, y, w, h)
#endif

#if ((TK_MAJOR_VERSION == 8) && (TK_MINOR_VERSION > 4))
/* TIP 116 */
#define tkimg_PhotoExpand(interp,hdl,w,h)  Tk_PhotoExpand(interp, hdl, w, h)
#else
#define tkimg_PhotoExpand(interp,hdl,w,h)  Tk_PhotoExpand(hdl, w, h)
#endif

#ifndef CONST84
/* TIP 27 */
#   define CONST84 /*empty*/
#endif

#endif /* __TKIMG_H__ */
